@@ -7,14 +7,15 @@
 #
 R=${R:-R}
 thisdir=`dirname $0` ; cd $thisdir; thisdir=`pwd`
-echo 'preliminary thisdir='$thisdir
+echo "R = '$R' (`$R --version | head -1`)
+  preliminary thisdir='$thisdir'"
 pkgDIR=`dirname $thisdir`
 pkg=`basename $pkgDIR`
 echo '  -->        pkgDIR='$pkgDIR' ; pkg='$pkg
 # echo ''; echo '## FIXME ## use new Scheme from R 3.0.x on'
 # cd `$R RHOME`/po
 # make pkg-update PKG=$pkg PKGDIR=$pkgDIR
-echo "require('tools'); update_pkg_po('$pkgDIR')" | $R --slave
+echo "require('tools'); update_pkg_po('$pkgDIR')" | $R --slave 2>&1 | tee update.log
 ##    --------------------------------  as of R 3.0.0
 echo 'end{make pkg-update}' ; echo ''
 echo 'Test with (e.g.)'
